abacusai.api_class.enums — AbacusAI documentation

# abacusai.api_class.enums

## Classes

`ApiEnum` | Generic enumeration.
`ProblemType` | Generic enumeration.
`RegressionObjective` | Generic enumeration.
`RegressionTreeHPOMode` | Generic enumeration.
`PartialDependenceAnalysis` | Generic enumeration.
`RegressionAugmentationStrategy` | Generic enumeration.
`RegressionTargetTransform` | Generic enumeration.
`RegressionTypeOfSplit` | Generic enumeration.
`RegressionTimeSplitMethod` | Generic enumeration.
`RegressionLossFunction` | Generic enumeration.
`ExplainerType` | Generic enumeration.
`SamplingMethodType` | Generic enumeration.
`MergeMode` | Generic enumeration.
`OperatorType` | Generic enumeration.
`MarkdownOperatorInputType` | Generic enumeration.
`FillLogic` | Generic enumeration.
`BatchSize` | Generic enumeration.
`HolidayCalendars` | Generic enumeration.
`FileFormat` | Generic enumeration.
`ExperimentationMode` | Generic enumeration.
`PersonalizationTrainingMode` | Generic enumeration.
`PersonalizationObjective` | Generic enumeration.
`ForecastingObjective` | Generic enumeration.
`ForecastingFrequency` | Generic enumeration.
`ForecastingDataSplitType` | Generic enumeration.
`ForecastingLossFunction` | Generic enumeration.
`ForecastingLocalScaling` | Generic enumeration.
`ForecastingFillMethod` | Generic enumeration.
`ForecastingQuanitlesExtensionMethod` | Generic enumeration.
`TimeseriesAnomalyDataSplitType` | Generic enumeration.
`TimeseriesAnomalyTypeOfAnomaly` | Generic enumeration.
`TimeseriesAnomalyUseHeuristic` | Generic enumeration.
`NERObjective` | Generic enumeration.
`NERModelType` | Generic enumeration.
`NLPDocumentFormat` | Generic enumeration.
`SentimentType` | Generic enumeration.
`ClusteringImputationMethod` | Generic enumeration.
`ConnectorType` | Generic enumeration.
`ApplicationConnectorType` | Generic enumeration.
`StreamingConnectorType` | Generic enumeration.
`PythonFunctionArgumentType` | Generic enumeration.
`PythonFunctionOutputArgumentType` | Generic enumeration.
`VectorStoreTextEncoder` | Generic enumeration.
`LLMName` | Generic enumeration.
`MonitorAlertType` | Generic enumeration.
`FeatureDriftType` | Generic enumeration.
`DataIntegrityViolationType` | Generic enumeration.
`BiasType` | Generic enumeration.
`AlertActionType` | Generic enumeration.
`PythonFunctionType` | Generic enumeration.
`EvalArtifactType` | Generic enumeration.
`FieldDescriptorType` | Generic enumeration.
`WorkflowNodeInputType` | Generic enumeration.
`WorkflowNodeOutputType` | Generic enumeration.
`OcrMode` | Generic enumeration.
`DocumentType` | Generic enumeration.
`StdDevThresholdType` | Generic enumeration.
`DataType` | Generic enumeration.
`AgentInterface` | Generic enumeration.
`WorkflowNodeTemplateType` | Generic enumeration.
`ProjectConfigType` | Generic enumeration.
`CPUSize` | Generic enumeration.
`MemorySize` | Generic enumeration.
`ResponseSectionType` | Generic enumeration.
`CodeLanguage` | Generic enumeration.
`DeploymentConversationType` | Generic enumeration.
`AgentClientType` | Generic enumeration.
`OrganizationSecretType` | Enum for organization secret types

## Functions

`deprecated_enums`(*enum_values) |

## Module Contents

abacusai.api_class.enums.deprecated_enums(*enum_values)

class abacusai.api_class.enums.ApiEnum

  Bases: `enum.Enum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  __deprecated_values__ = []
  is_deprecated()
  __eq__(other)
  __hash__()

class abacusai.api_class.enums.ProblemType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AI_AGENT = 'ai_agent'
  EVENT_ANOMALY = 'event_anomaly'
  CLUSTERING = 'clustering'
  CLUSTERING_TIMESERIES = 'clustering_timeseries'
  CUMULATIVE_FORECASTING = 'cumulative_forecasting'
  NAMED_ENTITY_EXTRACTION = 'nlp_ner'
  NATURAL_LANGUAGE_SEARCH = 'nlp_search'
  CHAT_LLM = 'chat_llm'
  SENTENCE_BOUNDARY_DETECTION = 'nlp_sentence_boundary_detection'
  SENTIMENT_DETECTION = 'nlp_sentiment'
  DOCUMENT_CLASSIFICATION = 'nlp_classification'
  DOCUMENT_SUMMARIZATION = 'nlp_summarization'
  DOCUMENT_VISUALIZATION = 'nlp_document_visualization'
  PERSONALIZATION = 'personalization'
  PREDICTIVE_MODELING = 'regression'
  FINETUNED_LLM = 'finetuned_llm'
  FORECASTING = 'forecasting'
  CUSTOM_TRAINED_MODEL = 'plug_and_play'
  CUSTOM_ALGORITHM = 'trainable_plug_and_play'
  FEATURE_STORE = 'feature_store'
  IMAGE_CLASSIFICATION = 'vision_classification'
  OBJECT_DETECTION = 'vision_object_detection'
  IMAGE_VALUE_PREDICTION = 'vision_regression'
  MODEL_MONITORING = 'model_monitoring'
  LANGUAGE_DETECTION = 'language_detection'
  OPTIMIZATION = 'optimization'
  PRETRAINED_MODELS = 'pretrained'
  THEME_ANALYSIS = 'theme_analysis'
  TS_ANOMALY = 'ts_anomaly'

class abacusai.api_class.enums.RegressionObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUC = 'auc'
  ACCURACY = 'acc'
  LOG_LOSS = 'log_loss'
  PRECISION = 'precision'
  RECALL = 'recall'
  F1_SCORE = 'fscore'
  MAE = 'mae'
  MAPE = 'mape'
  WAPE = 'wape'
  RMSE = 'rmse'
  R_SQUARED_COEFFICIENT_OF_DETERMINATION = 'r^2'

class abacusai.api_class.enums.RegressionTreeHPOMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RAPID = 'rapid'
  THOROUGH = 'thorough'

class abacusai.api_class.enums.PartialDependenceAnalysis

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RAPID = 'rapid'
  THOROUGH = 'thorough'

class abacusai.api_class.enums.RegressionAugmentationStrategy

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  SMOTE = 'smote'
  RESAMPLE = 'resample'

class abacusai.api_class.enums.RegressionTargetTransform

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  LOG = 'log'
  QUANTILE = 'quantile'
  YEO_JOHNSON = 'yeo-johnson'
  BOX_COX = 'box-cox'

class abacusai.api_class.enums.RegressionTypeOfSplit

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RANDOM = 'Random Sampling'
  TIMESTAMP_BASED = 'Timestamp Based'
  ROW_INDICATOR_BASED = 'Row Indicator Based'
  STRATIFIED_RANDOM_SAMPLING = 'Stratified Random Sampling'

class abacusai.api_class.enums.RegressionTimeSplitMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  TEST_SPLIT_PERCENTAGE_BASED = 'Test Split Percentage Based'
  TEST_START_TIMESTAMP_BASED = 'Test Start Timestamp Based'

class abacusai.api_class.enums.RegressionLossFunction

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  HUBER = 'Huber'
  MSE = 'Mean Squared Error'
  MAE = 'Mean Absolute Error'
  MAPE = 'Mean Absolute Percentage Error'
  MSLE = 'Mean Squared Logarithmic Error'
  TWEEDIE = 'Tweedie'
  CROSS_ENTROPY = 'Cross Entropy'
  FOCAL_CROSS_ENTROPY = 'Focal Cross Entropy'
  AUTOMATIC = 'Automatic'
  CUSTOM = 'Custom'

class abacusai.api_class.enums.ExplainerType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  KERNEL_EXPLAINER = 'KERNEL_EXPLAINER'
  LIME_EXPLAINER = 'LIME_EXPLAINER'
  TREE_EXPLAINER = 'TREE_EXPLAINER'
  EBM_EXPLAINER = 'EBM_EXPLAINER'

class abacusai.api_class.enums.SamplingMethodType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  N_SAMPLING = 'N_SAMPLING'
  PERCENT_SAMPLING = 'PERCENT_SAMPLING'

class abacusai.api_class.enums.MergeMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  LAST_N = 'LAST_N'
  TIME_WINDOW = 'TIME_WINDOW'

class abacusai.api_class.enums.OperatorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  UNPIVOT = 'UNPIVOT'
  MARKDOWN = 'MARKDOWN'
  CRAWLER = 'CRAWLER'
  EXTRACT_DOCUMENT_DATA = 'EXTRACT_DOCUMENT_DATA'
  DATA_GENERATION = 'DATA_GENERATION'
  UNION = 'UNION'

class abacusai.api_class.enums.MarkdownOperatorInputType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  HTML = 'HTML'

class abacusai.api_class.enums.FillLogic

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AVERAGE = 'average'
  MAX = 'max'
  MEDIAN = 'median'
  MIN = 'min'
  CUSTOM = 'custom'
  BACKFILL = 'bfill'
  FORWARDFILL = 'ffill'
  LINEAR = 'linear'
  NEAREST = 'nearest'

class abacusai.api_class.enums.BatchSize

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  BATCH_8 = 8
  BATCH_16 = 16
  BATCH_32 = 32
  BATCH_64 = 64
  BATCH_128 = 128
  BATCH_256 = 256
  BATCH_384 = 384
  BATCH_512 = 512
  BATCH_740 = 740
  BATCH_1024 = 1024

class abacusai.api_class.enums.HolidayCalendars

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AU = 'AU'
  UK = 'UK'
  US = 'US'

class abacusai.api_class.enums.FileFormat

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AVRO = 'AVRO'
  PARQUET = 'PARQUET'
  TFRECORD = 'TFRECORD'
  TSV = 'TSV'
  CSV = 'CSV'
  ORC = 'ORC'
  JSON = 'JSON'
  ODS = 'ODS'
  XLS = 'XLS'
  GZ = 'GZ'
  ZIP = 'ZIP'
  TAR = 'TAR'
  DOCX = 'DOCX'
  PDF = 'PDF'
  MD = 'md'
  RAR = 'RAR'
  GIF = 'GIF'
  JPEG = 'JPG'
  PNG = 'PNG'
  TIF = 'TIFF'
  NUMBERS = 'NUMBERS'
  PPTX = 'PPTX'
  PPT = 'PPT'
  HTML = 'HTML'
  TXT = 'txt'
  EML = 'eml'
  MP3 = 'MP3'
  MP4 = 'MP4'
  FLV = 'flv'
  MOV = 'mov'
  MPG = 'mpg'
  MPEG = 'mpeg'
  WEBP = 'webp'
  WEBM = 'webm'
  WMV = 'wmv'
  MSG = 'msg'

class abacusai.api_class.enums.ExperimentationMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RAPID = 'rapid'
  THOROUGH = 'thorough'

class abacusai.api_class.enums.PersonalizationTrainingMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  EXPERIMENTAL = 'EXP'
  PRODUCTION = 'PROD'

class abacusai.api_class.enums.PersonalizationObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  NDCG = 'ndcg'
  NDCG_5 = 'ndcg@5'
  NDCG_10 = 'ndcg@10'
  MAP = 'map'
  MAP_5 = 'map@5'
  MAP_10 = 'map@10'
  MRR = 'mrr'
  PERSONALIZATION = 'personalization@10'
  COVERAGE = 'coverage'

class abacusai.api_class.enums.ForecastingObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ACCURACY = 'w_c_accuracy'
  WAPE = 'wape'
  MAPE = 'mape'
  CMAPE = 'cmape'
  RMSE = 'rmse'
  CV = 'coefficient_of_variation'
  BIAS = 'bias'
  SRMSE = 'srmse'

class abacusai.api_class.enums.ForecastingFrequency

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  HOURLY = '1H'
  DAILY = '1D'
  WEEKLY_SUNDAY_START = '1W'
  WEEKLY_MONDAY_START = 'W-MON'
  WEEKLY_SATURDAY_START = 'W-SAT'
  MONTH_START = 'MS'
  MONTH_END = '1M'
  QUARTER_START = 'QS'
  QUARTER_END = '1Q'
  YEARLY = '1Y'

class abacusai.api_class.enums.ForecastingDataSplitType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTO = 'Automatic Time Based'
  TIMESTAMP = 'Timestamp Based'
  ITEM = 'Item Based'
  PREDICTION_LENGTH = 'Force Prediction Length'
  L_SHAPED_AUTO = 'L-shaped Split - Automatic Time Based'
  L_SHAPED_TIMESTAMP = 'L-shaped Split - Timestamp Based'

class abacusai.api_class.enums.ForecastingLossFunction

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  CUSTOM = 'Custom'
  MEAN_ABSOLUTE_ERROR = 'mae'
  NORMALIZED_MEAN_ABSOLUTE_ERROR = 'nmae'
  PEAKS_MEAN_ABSOLUTE_ERROR = 'peaks_mae'
  MEAN_ABSOLUTE_PERCENTAGE_ERROR = 'stable_mape'
  POINTWISE_ACCURACY = 'accuracy'
  ROOT_MEAN_SQUARE_ERROR = 'rmse'
  NORMALIZED_ROOT_MEAN_SQUARE_ERROR = 'nrmse'
  ASYMMETRIC_MEAN_ABSOLUTE_PERCENTAGE_ERROR = 'asymmetric_mape'
  STABLE_STANDARDIZED_MEAN_ABSOLUTE_PERCENTAGE_ERROR = 'stable_standardized_mape_with_cmape'
  GAUSSIAN = 'mle_gaussian_local'
  GAUSSIAN_FULL_COVARIANCE = 'mle_gaussfullcov'
  GUASSIAN_EXPONENTIAL = 'mle_gaussexp'
  MIX_GAUSSIANS = 'mle_gaussmix'
  WEIBULL = 'mle_weibull'
  NEGATIVE_BINOMIAL = 'mle_negbinom'
  LOG_ROOT_MEAN_SQUARE_ERROR = 'log_rmse'

class abacusai.api_class.enums.ForecastingLocalScaling

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ZSCORE = 'zscore'
  SLIDING_ZSCORE = 'sliding_zscore'
  LAST_POINT = 'lastpoint'
  MIN_MAX = 'minmax'
  MIN_STD = 'minstd'
  ROBUST = 'robust'
  ITEM = 'item'

class abacusai.api_class.enums.ForecastingFillMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  BACK = 'BACK'
  MIDDLE = 'MIDDLE'
  FUTURE = 'FUTURE'

class abacusai.api_class.enums.ForecastingQuanitlesExtensionMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  DIRECT = 'direct'
  QUADRATIC = 'quadratic'
  ANCESTRAL_SIMULATION = 'simulation'

class abacusai.api_class.enums.TimeseriesAnomalyDataSplitType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTO = 'Automatic Time Based'
  TIMESTAMP = 'Fixed Timestamp Based'

class abacusai.api_class.enums.TimeseriesAnomalyTypeOfAnomaly

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  HIGH_PEAK = 'high_peak'
  LOW_PEAK = 'low_peak'

class abacusai.api_class.enums.TimeseriesAnomalyUseHeuristic

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ENABLE = 'enable'
  DISABLE = 'disable'
  AUTOMATIC = 'automatic'

class abacusai.api_class.enums.NERObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  LOG_LOSS = 'log_loss'
  AUC = 'auc'
  PRECISION = 'precision'
  RECALL = 'recall'
  ANNOTATIONS_PRECISION = 'annotations_precision'
  ANNOTATIONS_RECALL = 'annotations_recall'

class abacusai.api_class.enums.NERModelType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  PRETRAINED_BERT = 'pretrained_bert'
  PRETRAINED_ROBERTA_27 = 'pretrained_roberta_27'
  PRETRAINED_ROBERTA_43 = 'pretrained_roberta_43'
  PRETRAINED_MULTILINGUAL = 'pretrained_multilingual'
  LEARNED = 'learned'

class abacusai.api_class.enums.NLPDocumentFormat

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTO = 'auto'
  TEXT = 'text'
  DOC = 'doc'
  TOKENS = 'tokens'

class abacusai.api_class.enums.SentimentType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  VALENCE = 'valence'
  EMOTION = 'emotion'

class abacusai.api_class.enums.ClusteringImputationMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTOMATIC = 'Automatic'
  ZEROS = 'Zeros'
  INTERPOLATE = 'Interpolate'

class abacusai.api_class.enums.ConnectorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FILE = 'FILE'
  DATABASE = 'DATABASE'
  STREAMING = 'STREAMING'
  APPLICATION = 'APPLICATION'

class abacusai.api_class.enums.ApplicationConnectorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  GOOGLEANALYTICS = 'GOOGLEANALYTICS'
  GOOGLEDRIVE = 'GOOGLEDRIVE'
  GOOGLECALENDAR = 'GOOGLECALENDAR'
  GIT = 'GIT'
  CONFLUENCE = 'CONFLUENCE'
  JIRA = 'JIRA'
  ONEDRIVE = 'ONEDRIVE'
  ZENDESK = 'ZENDESK'
  SLACK = 'SLACK'
  SHAREPOINT = 'SHAREPOINT'
  TEAMS = 'TEAMS'
  ABACUSUSAGEMETRICS = 'ABACUSUSAGEMETRICS'
  MICROSOFTAUTH = 'MICROSOFTAUTH'
  FRESHSERVICE = 'FRESHSERVICE'
  ZENDESKSUNSHINEMESSAGING = 'ZENDESKSUNSHINEMESSAGING'
  GOOGLEDRIVEUSER = 'GOOGLEDRIVEUSER'
  GOOGLEWORKSPACEUSER = 'GOOGLEWORKSPACEUSER'
  GMAILUSER = 'GMAILUSER'
  GOOGLESHEETS = 'GOOGLESHEETS'
  GOOGLEDOCS = 'GOOGLEDOCS'
  TEAMSSCRAPER = 'TEAMSSCRAPER'
  GITHUBUSER = 'GITHUBUSER'
  OKTASAML = 'OKTASAML'
  BOX = 'BOX'
  SFTPAPPLICATION = 'SFTPAPPLICATION'
  OAUTH = 'OAUTH'
  SALESFORCE = 'SALESFORCE'
  TWITTER = 'TWITTER'
  MCP = 'MCP'
  ODBC = 'ODBC'
  DBC = 'DBC'
  classmethod user_connectors()
  classmethod database_connectors()

class abacusai.api_class.enums.StreamingConnectorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  KAFKA = 'KAFKA'

class abacusai.api_class.enums.PythonFunctionArgumentType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FEATURE_GROUP = 'FEATURE_GROUP'
  INTEGER = 'INTEGER'
  STRING = 'STRING'
  BOOLEAN = 'BOOLEAN'
  FLOAT = 'FLOAT'
  JSON = 'JSON'
  LIST = 'LIST'
  DATASET_ID = 'DATASET_ID'
  MODEL_ID = 'MODEL_ID'
  FEATURE_GROUP_ID = 'FEATURE_GROUP_ID'
  MONITOR_ID = 'MONITOR_ID'
  BATCH_PREDICTION_ID = 'BATCH_PREDICTION_ID'
  DEPLOYMENT_ID = 'DEPLOYMENT_ID'
  ATTACHMENT = 'ATTACHMENT'
  static to_json_type(type)

class abacusai.api_class.enums.PythonFunctionOutputArgumentType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  NTEGER = 'INTEGER'
  STRING = 'STRING'
  BOOLEAN = 'BOOLEAN'
  FLOAT = 'FLOAT'
  JSON = 'JSON'
  LIST = 'LIST'
  DATASET_ID = 'DATASET_ID'
  MODEL_ID = 'MODEL_ID'
  FEATURE_GROUP_ID = 'FEATURE_GROUP_ID'
  MONITOR_ID = 'MONITOR_ID'
  BATCH_PREDICTION_ID = 'BATCH_PREDICTION_ID'
  DEPLOYMENT_ID = 'DEPLOYMENT_ID'
  ANY = 'ANY'
  ATTACHMENT = 'ATTACHMENT'

class abacusai.api_class.enums.VectorStoreTextEncoder

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  E5 = 'E5'
  OPENAI = 'OPENAI'
  OPENAI_COMPACT = 'OPENAI_COMPACT'
  OPENAI_LARGE = 'OPENAI_LARGE'
  SENTENCE_BERT = 'SENTENCE_BERT'
  E5_SMALL = 'E5_SMALL'
  CODE_BERT = 'CODE_BERT'

class abacusai.api_class.enums.LLMName

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  OPENAI_GPT3_5 = 'OPENAI_GPT3_5'
  OPENAI_GPT3_5_TEXT = 'OPENAI_GPT3_5_TEXT'
  OPENAI_GPT4 = 'OPENAI_GPT4'
  OPENAI_GPT4_32K = 'OPENAI_GPT4_32K'
  OPENAI_GPT4_128K = 'OPENAI_GPT4_128K'
  OPENAI_GPT4_128K_LATEST = 'OPENAI_GPT4_128K_LATEST'
  OPENAI_GPT4O = 'OPENAI_GPT4O'
  OPENAI_GPT4O_MINI = 'OPENAI_GPT4O_MINI'
  OPENAI_O1_MINI = 'OPENAI_O1_MINI'
  OPENAI_O3 = 'OPENAI_O3'
  OPENAI_O3_HIGH = 'OPENAI_O3_HIGH'
  OPENAI_O4_MINI = 'OPENAI_O4_MINI'
  OPENAI_O4_MINI_HIGH = 'OPENAI_O4_MINI_HIGH'
  OPENAI_GPT4_1 = 'OPENAI_GPT4_1'
  OPENAI_GPT4_1_MINI = 'OPENAI_GPT4_1_MINI'
  OPENAI_GPT4_1_NANO = 'OPENAI_GPT4_1_NANO'
  OPENAI_GPT5 = 'OPENAI_GPT5'
  OPENAI_GPT5_MINI = 'OPENAI_GPT5_MINI'
  OPENAI_GPT5_MINI_HIGH = 'OPENAI_GPT5_MINI_HIGH'
  OPENAI_GPT5_MINI_LOW = 'OPENAI_GPT5_MINI_LOW'
  OPENAI_GPT5_NANO = 'OPENAI_GPT5_NANO'
  OPENAI_GPT5_NANO_HIGH = 'OPENAI_GPT5_NANO_HIGH'
  CLAUDE_V3_HAIKU = 'CLAUDE_V3_HAIKU'
  CLAUDE_V3_OPUS = 'CLAUDE_V3_OPUS'
  CLAUDE_V3_5_HAIKU = 'CLAUDE_V3_5_HAIKU'
  CLAUDE_V3_5_SONNET = 'CLAUDE_V3_5_SONNET'
  CLAUDE_V3_7_SONNET = 'CLAUDE_V3_7_SONNET'
  CLAUDE_V4_SONNET = 'CLAUDE_V4_SONNET'
  CLAUDE_V4_OPUS = 'CLAUDE_V4_OPUS'
  GEMINI_1_5_PRO = 'GEMINI_1_5_PRO'
  GEMINI_1_5_FLASH = 'GEMINI_1_5_FLASH'
  GEMINI_2_PRO = 'GEMINI_2_PRO'
  GEMINI_2_FLASH = 'GEMINI_2_FLASH'
  GEMINI_2_5_PRO = 'GEMINI_2_5_PRO'
  GEMINI_2_5_FLASH = 'GEMINI_2_5_FLASH'
  GEMINI_2_FLASH_THINKING = 'GEMINI_2_FLASH_THINKING'
  XAI_GROK = 'XAI_GROK'
  XAI_GROK_3 = 'XAI_GROK_3'
  XAI_GROK_3_MINI = 'XAI_GROK_3_MINI'
  XAI_GROK_4 = 'XAI_GROK_4'
  LLAMA4_MAVERICK = 'LLAMA4_MAVERICK'
  LLAMA3_1_405B = 'LLAMA3_1_405B'
  LLAMA3_1_70B = 'LLAMA3_1_70B'
  LLAMA3_1_8B = 'LLAMA3_1_8B'
  LLAMA3_3_70B = 'LLAMA3_3_70B'
  LLAMA3_LARGE_CHAT = 'LLAMA3_LARGE_CHAT'
  ABACUS_SMAUG3 = 'ABACUS_SMAUG3'
  ABACUS_DRACARYS = 'ABACUS_DRACARYS'
  QWEN_2_5_32B = 'QWEN_2_5_32B'
  QWEN_2_5_32B_BASE = 'QWEN_2_5_32B_BASE'
  QWEN_2_5_72B = 'QWEN_2_5_72B'
  QWQ_32B = 'QWQ_32B'
  QWEN3_32B = 'QWEN3_32B'
  QWEN3_235B_A22B = 'QWEN3_235B_A22B_2507'
  QWEN3_235B_A22B_THINKING = 'QWEN3_235B_A22B_THINKING_2507'
  QWEN3_CODER = 'QWEN3_CODER'
  DEEPSEEK_V3_1 = 'DEEPSEEK_V3_1'
  DEEPSEEK_R1 = 'DEEPSEEK_R1'

class abacusai.api_class.enums.MonitorAlertType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ACCURACY_BELOW_THRESHOLD = 'AccuracyBelowThreshold'
  FEATURE_DRIFT = 'FeatureDrift'
  DATA_INTEGRITY_VIOLATIONS = 'DataIntegrityViolations'
  BIAS_VIOLATIONS = 'BiasViolations'
  HISTORY_LENGTH_DRIFT = 'HistoryLengthDrift'
  TARGET_DRIFT = 'TargetDrift'
  PREDICTION_COUNT = 'PredictionCount'

class abacusai.api_class.enums.FeatureDriftType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  KL = 'kl'
  KS = 'ks'
  WS = 'ws'
  JS = 'js'
  PSI = 'psi'
  CHI_SQUARE = 'chi_square'
  CSI = 'csi'

class abacusai.api_class.enums.DataIntegrityViolationType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  NULL_VIOLATIONS = 'null_violations'
  RANGE_VIOLATIONS = 'range_violations'
  CATEGORICAL_RANGE_VIOLATION = 'categorical_range_violations'
  TOTAL_VIOLATIONS = 'total_violations'

class abacusai.api_class.enums.BiasType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  DEMOGRAPHIC_PARITY = 'demographic_parity'
  EQUAL_OPPORTUNITY = 'equal_opportunity'
  GROUP_BENEFIT_EQUALITY = 'group_benefit'
  TOTAL = 'total'

class abacusai.api_class.enums.AlertActionType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  EMAIL = 'Email'

class abacusai.api_class.enums.PythonFunctionType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FEATURE_GROUP = 'FEATURE_GROUP'
  PLOTLY_FIG = 'PLOTLY_FIG'
  STEP_FUNCTION = 'STEP_FUNCTION'
  USERCODE_TOOL = 'USERCODE_TOOL'
  CONNECTOR_TOOL = 'CONNECTOR_TOOL'

class abacusai.api_class.enums.EvalArtifactType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FORECASTING_ACCURACY = 'bar_chart'
  FORECASTING_VOLUME = 'bar_chart_volume'
  FORECASTING_HISTORY_LENGTH_ACCURACY = 'bar_chart_accuracy_by_history'

class abacusai.api_class.enums.FieldDescriptorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  STRING = 'STRING'
  INTEGER = 'INTEGER'
  FLOAT = 'FLOAT'
  BOOLEAN = 'BOOLEAN'
  DATETIME = 'DATETIME'
  DATE = 'DATE'

class abacusai.api_class.enums.WorkflowNodeInputType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  USER_INPUT = 'USER_INPUT'
  WORKFLOW_VARIABLE = 'WORKFLOW_VARIABLE'
  IGNORE = 'IGNORE'
  CONSTANT = 'CONSTANT'

class abacusai.api_class.enums.WorkflowNodeOutputType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ATTACHMENT = 'ATTACHMENT'
  BOOLEAN = 'BOOLEAN'
  FLOAT = 'FLOAT'
  INTEGER = 'INTEGER'
  DICT = 'DICT'
  LIST = 'LIST'
  STRING = 'STRING'
  RUNTIME_SCHEMA = 'RUNTIME_SCHEMA'
  ANY = 'ANY'
  classmethod normalize_type(python_type)
    Parameters:

      python_type (Union[str, type, None, WorkflowNodeOutputType, PythonFunctionOutputArgumentType])

    Return type:

      WorkflowNodeOutputType

class abacusai.api_class.enums.OcrMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTO = 'AUTO'
  DEFAULT = 'DEFAULT'
  LAYOUT = 'LAYOUT'
  SCANNED = 'SCANNED'
  COMPREHENSIVE = 'COMPREHENSIVE'
  COMPREHENSIVE_V2 = 'COMPREHENSIVE_V2'
  COMPREHENSIVE_TABLE_MD = 'COMPREHENSIVE_TABLE_MD'
  COMPREHENSIVE_FORM_MD = 'COMPREHENSIVE_FORM_MD'
  COMPREHENSIVE_FORM_AND_TABLE_MD = 'COMPREHENSIVE_FORM_AND_TABLE_MD'
  TESSERACT_FAST = 'TESSERACT_FAST'
  LLM = 'LLM'
  AUGMENTED_LLM = 'AUGMENTED_LLM'
  classmethod aws_ocr_modes()

class abacusai.api_class.enums.DocumentType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  SIMPLE_TEXT = 'SIMPLE_TEXT'
  TEXT = 'TEXT'
  TABLES_AND_FORMS = 'TABLES_AND_FORMS'
  EMBEDDED_IMAGES = 'EMBEDDED_IMAGES'
  SCANNED_TEXT = 'SCANNED_TEXT'
  COMPREHENSIVE_MARKDOWN = 'COMPREHENSIVE_MARKDOWN'
  classmethod is_ocr_forced(document_type)
    Parameters:

      document_type (DocumentType)

class abacusai.api_class.enums.StdDevThresholdType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ABSOLUTE = 'ABSOLUTE'
  PERCENTILE = 'PERCENTILE'
  STDDEV = 'STDDEV'

class abacusai.api_class.enums.DataType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  INTEGER = 'integer'
  FLOAT = 'float'
  STRING = 'string'
  DATE = 'date'
  DATETIME = 'datetime'
  BOOLEAN = 'boolean'
  LIST = 'list'
  STRUCT = 'struct'
  NULL = 'null'
  BINARY = 'binary'

class abacusai.api_class.enums.AgentInterface

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  DEFAULT = 'DEFAULT'
  CHAT = 'CHAT'
  MATRIX = 'MATRIX'
  AUTONOMOUS = 'AUTONOMOUS'

class abacusai.api_class.enums.WorkflowNodeTemplateType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  TRIGGER = 'trigger'
  DEFAULT = 'default'

class abacusai.api_class.enums.ProjectConfigType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  CONSTRAINTS = 'CONSTRAINTS'
  CHAT_FEEDBACK = 'CHAT_FEEDBACK'
  REVIEW_MODE = 'REVIEW_MODE'

class abacusai.api_class.enums.CPUSize

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  SMALL = 'small'
  MEDIUM = 'medium'
  LARGE = 'large'

class abacusai.api_class.enums.MemorySize

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  SMALL = 16
  MEDIUM = 32
  LARGE = 64
  XLARGE = 128
  classmethod from_value(value)

class abacusai.api_class.enums.ResponseSectionType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AGENT_FLOW_BUTTON = 'agent_flow_button'
  ATTACHMENTS = 'attachments'
  BASE64_IMAGE = 'base64_image'
  CHART = 'chart'
  CODE = 'code'
  COLLAPSIBLE_COMPONENT = 'collapsible_component'
  IMAGE_URL = 'image_url'
  RUNTIME_SCHEMA = 'runtime_schema'
  LIST = 'list'
  TABLE = 'table'
  TEXT = 'text'

class abacusai.api_class.enums.CodeLanguage

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  PYTHON = 'python'
  SQL = 'sql'

class abacusai.api_class.enums.DeploymentConversationType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  CHAT_LLM = 'CHATLLM'
  SIMPLE_AGENT = 'SIMPLE_AGENT'
  COMPLEX_AGENT = 'COMPLEX_AGENT'
  WORKFLOW_AGENT = 'WORKFLOW_AGENT'
  COPILOT = 'COPILOT'
  AGENT_CONTROLLER = 'AGENT_CONTROLLER'
  CODE_LLM = 'CODE_LLM'
  CODE_LLM_AGENT = 'CODE_LLM_AGENT'
  CHAT_LLM_TASK = 'CHAT_LLM_TASK'
  COMPUTER_AGENT = 'COMPUTER_AGENT'
  SEARCH_LLM = 'SEARCH_LLM'
  APP_LLM = 'APP_LLM'
  TEST_AGENT = 'TEST_AGENT'
  SUPER_AGENT = 'SUPER_AGENT'
  CODE_LLM_NON_INTERACTIVE = 'CODE_LLM_NON_INTERACTIVE'

class abacusai.api_class.enums.AgentClientType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  CHAT_UI = 'CHAT_UI'
  MESSAGING_APP = 'MESSAGING_APP'
  API = 'API'

class abacusai.api_class.enums.OrganizationSecretType

  Bases: `ApiEnum`

  Enum for organization secret types

  ORG_SECRET = 'ORG_SECRET'
  ORG_API_CREDENTIALS = 'ORG_API_CREDENTIALS'
  USER_API_CREDENTIALS = 'USER_API_CREDENTIALS'